@@ -1,5 +1,6 @@
+import random
 import extraEncodings.ciphers as ciphers
-fomr ciphers import *
+from ciphers import *
 class TwoWayDict(dict):
     def __init__(self, my_dict):
         dict.__init__(self, my_dict)
@@ -27,16 +28,28 @@ class Encoding():
             x = x + rate
             self.encodingnormal[letter] = x
         self.encoding = TwoWayDict(self.encodingnormal)
-
 class ListEncoding():
     def __init__(self,mix):
         self.encoding = []
         self.mix = mix
         for letter in Encodeable_letters:
             self.encoding.append(letter)
-    def encode(self,Character_to_decode):
+    def code(self,Character_to_decode):
         Character_to_decode = str(Character_to_decode)
         for character in Character_to_decode:
             charpos = self.encoding.index(character)
             ResultStr = str(self.encoding[-charpos  -self.mix])
-            print(ResultStr,end='') 
\ No newline at end of file
+            print(ResultStr,end='')
+class RandomEncoding():
+    '''A way to generate a random encoding for your purposes. \n
+    Encoding and decoding works the same as Encoding() \n
+    Look at CreateAnEncoding.py and the Encoding() for an example of how to use it.
+    '''
+    def __init__(self,MaxRandom,MinRandom):
+        self.rate = random.randint(MinRandom,MaxRandom)
+        x = 0
+        self.encodingnormal = {}
+        for letter in Encodeable_letters:
+            x = x + self.rate
+            self.encodingnormal[letter] = x
+        self.encoding = TwoWayDict(self.encodingnormal)
